@@ -15,7 +15,11 @@ class AMS():
             print("...collecting addresses, done with {} addresses".format(offset*take))
 
             try:
-                url = "https://ams.btcs{}.net/api/AddressManagement/addresses?Skip={}&Take={}&AccountRef={}&BlockchainId={}&IncludeBalances={}".format(self.env, offset*take, take, account, blockchain_id, include_balances)
+                url = ""
+                if blockchain_id:
+                    url = "https://ams.btcs{}.net/api/AddressManagement/addresses?Skip={}&Take={}&AccountRef={}&BlockchainId={}&IncludeBalances={}".format(self.env, offset*take, take, account, blockchain_id, include_balances)
+                else:
+                    url = "https://ams.btcs{}.net/api/AddressManagement/addresses?Skip={}&Take={}&AccountRef={}&IncludeBalances={}".format(self.env, offset*take, take, account, include_balances)
                 response = requests.request("GET", url)
                 addresses_res = response.json()
                 addresses.extend(addresses_res)
